==> ulyxex.0.0.7.with-tinyMce.zip: index.php <==
<?php
/****************************************/
/* required								*/
require("config.php");
require("pages/code/translate.php");
require("pages/code/html.php");
require("pages/code/ulyxex.php");
require("pages/code/tree.php");

/****************************************/
/* object 								*/
$h = new Html();
$tr = new Translate();

/****************************************/
/* you are in website					*/
$index = 1;

/****************************************/
/* 	associated actions and scripts		*/
/****************************************/
/* Article								*/
if (isset($_GET['art'])) {				
	$artId = $h->num($_GET['art']);
	require("pages/view_article.php");
/****************************************/
/* Page or link 						*/
} elseif (isset($_GET['cat'])) {
	/* link 							*/
	if (substr($_GET['cat'],0,4) == "link") {		
		$linkId = $h->num(substr($_GET['cat'],4)); 
		/* call the script				*/
		require("pages/view_link.php");
	} else {
		$catId = $h->num($_GET['cat']);
		require("pages/view_page.php");
	}
/****************************************/
/* User	profile							*/
} elseif (isset($_GET['user'])) {
	$userId = $h->num($_GET['user']);
	require("pages/view_user.php");
/****************************************/
/* Contact								*/
} elseif (isset($_GET['contact'])) {
	$contact = $h->word($_GET['contact']);
	require("pages/view_contact.php");
/****************************************/
/* Default								*/
} else {
	$o_default = new Ulyxex();
	$values = $o_default->home_params();
	$catId = $values['PAGEID'];
	require("pages/view_page.php");
/****************************************/
}
?>

==> ulyxex.0.1.0.with-tinyMce.zip: index.php <==
<?php
/****************************************/
/* required								*/
require("config.php");
require("pages/code/translate.php");
require("pages/code/html.php");
require("pages/code/ulyxex.php");
require("pages/code/tree.php");

/****************************************/
/* object 								*/
$h = new Html();
$tr = new Translate();

/****************************************/
/* you are in front end					*/
$index = 1;

/****************************************/
/* 	associated actions and scripts		*/
/****************************************/
/* Article								*/
if (isset($_GET['art'])) {				
	$artId = $h->num($_GET['art']);
	require("pages/view_article.php");
/****************************************/
/* Page or link 						*/
} elseif (isset($_GET['navpage']) || isset($_POST['navpage'])) {
	$pageParam = (isset($_GET['navpage']))?$_GET['navpage']:$_POST['navpage'];
	/* link 							*/
	if (substr($pageParam,0,4) == "link") {		
		$linkId = $h->num(substr($pageParam,4)); 
		/* call the script				*/
		require("pages/view_link.php");
	} else {
		$pageId = $h->num($pageParam);
		require("pages/view_page.php");
	}
/****************************************/
/* User	profile							*/
} elseif (isset($_GET['user'])) {
	$userId = $h->num($_GET['user']);
	require("pages/view_user.php");
/****************************************/
/* Contact								*/
} elseif (isset($_GET['contact'])) {
	$contact = $h->word($_GET['contact']);
	require("pages/view_contact.php");
/****************************************/
/* Default								*/
} else {
	$o_default = new Ulyxex();
	$values = $o_default->home_params();
	$pageId = $values['PAGEID'];
	require("pages/view_page.php");
/****************************************/
}
?>
